@@ -25,10 +25,7 @@ assay_facets: Facets = {
                 "Assay Type|IHC|All IHC Files|/ihc",
                 "Assay Type|Olink|All Olink Files|/olink",
                 "clinical_data|Assay Metadata",
-                "cytof_10021_9204|Assay Metadata",
-                "cytof_10021|Assay Metadata",
-                "cytof_e4412|Assay Metadata",
-                "cytof_s1609_gd2car|Assay Metadata",
+                "cytof|Assay Metadata",
                 "elisa|Assay Metadata",
                 "hande|Assay Metadata",
                 "ihc|Assay Metadata",
@@ -45,10 +42,7 @@ assay_facets: Facets = {
         ),
         "Analyses": FacetConfig(
             [
-                "cytof_10021_9204_analysis|Assay Metadata",
-                "cytof_10021_analysis|Assay Metadata",
-                "cytof_s1609_gd2car_analysis|Assay Metadata",
-                "cytof_e4412_analysis|Assay Metadata",
+                "cytof_analysis|Assay Metadata",
                 "rna_level1_analysis|Assay Metadata",
                 "tcr_analysis|Assay Metadata",
                 "wes_analysis|Assay Metadata",
@@ -57,6 +51,7 @@ assay_facets: Facets = {
             "Excel templates used to upload analysis data.",
         ),
     },
+    "Miscellaneous": {"All": FacetConfig(["/misc_data/"])},
     "Nanostring": {
         "Source": FacetConfig(
             ["/nanostring/.rcc", "/nanostring/control.rcc"],
@@ -70,20 +65,12 @@ assay_facets: Facets = {
     "CyTOF": {
         "Source": FacetConfig(
             [
-                "/cytof_10021_9204/spike_in.fcs",
-                "/cytof_10021_9204/source_.fcs",
-                "/cytof_10021_9024/normalized_and_debarcoded.fcs",
-                "/cytof_10021_9204/processed.fcs",
-                "/cytof_e4412/spike_in.fcs",
-                "/cytof_e4412/source_.fcs",
-                "/cytof_e4412/normalized_and_debarcoded.fcs",
-                "/cytof_e4412/processed.fcs",
-                "/cytof_s1609_gd2car/spike_in.fcs",
-                "/cytof_s1609_gd2car/source_.fcs",
-                "/cytof_s1609_gd2car/normalized_and_debarcoded.fcs",
-                "/cytof_s1609_gd2car/processed.fcs",
-                "/cytof_s1609_gd2car/control_.fcs",
-                "/cytof_s1609_gd2car/control__spike_in.fcs",
+                "/cytof/spike_in.fcs",
+                "/cytof/source_.fcs",
+                "/cytof/normalized_and_debarcoded.fcs",
+                "/cytof/processed.fcs",
+                "/cytof/control_.fcs",
+                "/cytof/control__spike_in.fcs",
             ],
             "De-barcoded, concatenated and de-multipled fcs files",
         ),
@@ -120,7 +107,6 @@ assay_facets: Facets = {
             ],
             "Keys for mapping from respective enumeration indices to the cell labels",
         ),
-        "Intermediates": FacetConfig(["/cytof_10021_9204/intermediate.fcs"]),
     },
     "WES": {
         "Source": FacetConfig(
@@ -241,7 +227,7 @@ assay_facets: Facets = {
                 "/wes_tumor_only/analysis/maf_tnscope_output.maf",
                 "/wes_tumor_only/analysis/vcf_gz_tnscope_filter.vcf.gz",
                 "/wes_tumor_only/analysis/maf_tnscope_filter.maf",
-                "/wes_tumor_only/analysis/tnscope_exons.vcf.gz"
+                "/wes_tumor_only/analysis/tnscope_exons.vcf.gz",
                 "/wes_tumor_only/analysis/vcf_compare.txt",
             ]
         ),
@@ -385,12 +371,11 @@ assay_facets: Facets = {
         ),
         "Misc.": FacetConfig(["/tcr/SampleSheet.csv" "/tcr_analysis/summary_info.csv"]),
         "Analysis Data": FacetConfig(
-            [
-                "/tcr_analysis/tra_clone.csv",
-                "/tcr_analysis/trb_clone.csv",
-                "/tcr_analysis/report_trial.tar.gz",
-            ],
-            "Data files and Report from TCRseq analysis indicating TRA & TRB clones' UMI counts",
+            ["/tcr_analysis/tra_clone.csv", "/tcr_analysis/trb_clone.csv",],
+            "Data files indicating TRA & TRB clones' UMI counts",
+        ),
+        "Reports": FacetConfig(
+            ["/tcr_analysis/report_trial.tar.gz",], "Report from TCRseq analysis",
         ),
     },
     "ELISA": {"Data": FacetConfig(["/elisa/assay.xlsx"])},
